SyncManager

Struct SyncManager 

pub struct SyncManager<S: CheckpointStore> { /* private fields */ }
Manager for handling sync operations with checkpoint tracking.

The SyncManager is generic over the checkpoint store type S, providing storage-agnostic checkpoint management.

Implementations

Source

impl<S: CheckpointStore> SyncManager<S>

pub fn new(store: S) -> Self

Create a new sync manager with the given store.

By default, checkpoint emission is enabled.

pub fn new_without_emit(store: S) -> Self

Create a new sync manager with checkpoint emission disabled.

pub fn with_emit_checkpoints(self, emit: bool) -> Self

Set whether to emit checkpoints.

pub fn emit_checkpoints(&self) -> bool

Check if checkpoint emission is enabled.

pub fn store(&self) -> &S

Get a reference to the underlying store.

pub async fn emit_checkpoint<C: Checkpoint>( &self, checkpoint: &C, phase: SyncPhase, ) -> Result<()>

Emit checkpoint for any database-specific checkpoint type.

pub async fn read_checkpoint<C: Checkpoint>( &self, phase: SyncPhase, ) -> Result<C>

Read and parse checkpoint into database-specific type.

Source

impl SyncManager<NullStore>

pub fn disabled() -> Self

Create a sync manager that does nothing (for disabled checkpoint storage).