pub struct Row {
pub table: String,
pub index: u64,
pub id: Value,
pub fields: HashMap<String, Value>,
}Expand description
Internal row representation - the intermediate format.
Row represents a single row of data in the intermediate format,
produced by the data generator and consumed by both source populators
and the streaming verifier.
Fields
table: StringTable name
index: u64Row index (for incremental support and reproducibility)
id: ValuePrimary key value
fields: HashMap<String, Value>Field values (column name -> value)
Implementations
Sourceimpl Row
impl Row
Sourcepub fn new(
table: impl Into<String>,
index: u64,
id: Value,
fields: HashMap<String, Value>,
) -> Self
pub fn new( table: impl Into<String>, index: u64, id: Value, fields: HashMap<String, Value>, ) -> Self
Create a new internal row.
Sourcepub fn builder(table: impl Into<String>, index: u64, id: Value) -> RowBuilder
pub fn builder(table: impl Into<String>, index: u64, id: Value) -> RowBuilder
Create a new internal row with a builder pattern.
Sourcepub fn field_count(&self) -> usize
pub fn field_count(&self) -> usize
Get the number of fields (excluding the id).