Value representations for the surreal-sync load testing framework.
This module defines the intermediate value types used for data generation and type conversion between different database systems.
Structs
- Change
- A database-agnostic change event for incremental sync.
- Geometry
Data - Geometry data representation.
- Relation
- A database-agnostic graph relation/edge.
- Row
- Internal row representation - the intermediate format.
- RowBuilder
- Builder for
Row. - RowConverter
- Converter that holds schema context for From implementations.
- Thing
Ref - A reference to a record/node in a specific table.
- Typed
Value - Typed value with its Type for conversion.
- Typed
Value Error - Error when creating a TypedValue with mismatched type and value.
Enums
- Change
Op - Operation type for incremental sync changes.
- Value
- Universal value representation with 1:1 correspondence to
Type. - Zero
Temporal Policy - How the SurrealDB sink represents
Value::ZeroTemporal.